@@ -373,12 +373,12 @@ if __name__ == '__main__':
     #                                           host_id="8bb7f77c-d3bf-432b-85e8-8094ba0e8cd5"
     #                                           )
     # print(rs)
-    # rs = cloudpods.create_server_by_guest_image("8572ed8a-6ffe-451a-80ac-c04da95e777f",
-    #                                             "1fdfbc15-e319-4f59-8e2b-cc45bc3517cb",
-    #                                             "x86_64", 20480, [20], ["265005a2-b3a4-42e3-8154-471bdd694487"],
-    #                                             "demo2", hypervisor="baremetal", bios="UEFI"
-    #                                             )
-    # print(rs)
+    rs = cloudpods.create_server_by_guest_image("8572ed8a-6ffe-451a-80ac-c04da95e777f",
+                                                "1fdfbc15-e319-4f59-8e2b-cc45bc3517cb",
+                                                "x86_64", 20480, [20], ["265005a2-b3a4-42e3-8154-471bdd694487"],
+                                                "demo2", hypervisor="baremetal", bios="UEFI"
+                                                )
+    print(rs)
     # rs=cloudpods.get_host_spec("25ca9007-111b-401e-82a0-34a4d208805b")
     # print(rs)
     # print(rs["host"]["cpu"])
